# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/paul/PycharmProjects/pySprida/pySprida/gui/main.ui'
#
# Created by: PyQt5 UI code generator 5.15.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(802, 600)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.label = QtWidgets.QLabel(self.centralwidget)
        self.label.setGeometry(QtCore.QRect(10, 10, 81, 18))
        self.label.setObjectName("label")
        self.config_path_select_button = QtWidgets.QPushButton(self.centralwidget)
        self.config_path_select_button.setGeometry(QtCore.QRect(420, 30, 121, 34))
        self.config_path_select_button.setObjectName("config_path_select_button")
        self.config_path = QtWidgets.QLineEdit(self.centralwidget)
        self.config_path.setGeometry(QtCore.QRect(10, 30, 401, 32))
        self.config_path.setObjectName("config_path")
        self.load_config_button = QtWidgets.QPushButton(self.centralwidget)
        self.load_config_button.setGeometry(QtCore.QRect(560, 30, 88, 34))
        self.load_config_button.setObjectName("load_config_button")
        self.generate_button = QtWidgets.QPushButton(self.centralwidget)
        self.generate_button.setGeometry(QtCore.QRect(10, 440, 161, 91))
        self.generate_button.setObjectName("generate_button")
        self.solver_selector = QtWidgets.QComboBox(self.centralwidget)
        self.solver_selector.setGeometry(QtCore.QRect(10, 110, 87, 32))
        self.solver_selector.setObjectName("solver_selector")
        self.solver_selector.addItem("")
        self.label_2 = QtWidgets.QLabel(self.centralwidget)
        self.label_2.setGeometry(QtCore.QRect(10, 90, 58, 18))
        self.label_2.setObjectName("label_2")
        self.label_3 = QtWidgets.QLabel(self.centralwidget)
        self.label_3.setGeometry(QtCore.QRect(190, 440, 58, 18))
        self.label_3.setObjectName("label_3")
        self.label_4 = QtWidgets.QLabel(self.centralwidget)
        self.label_4.setGeometry(QtCore.QRect(190, 460, 58, 18))
        self.label_4.setObjectName("label_4")
        self.label_5 = QtWidgets.QLabel(self.centralwidget)
        self.label_5.setGeometry(QtCore.QRect(190, 480, 58, 18))
        self.label_5.setObjectName("label_5")
        self.label_6 = QtWidgets.QLabel(self.centralwidget)
        self.label_6.setGeometry(QtCore.QRect(190, 500, 58, 18))
        self.label_6.setObjectName("label_6")
        self.status = QtWidgets.QLabel(self.centralwidget)
        self.status.setGeometry(QtCore.QRect(260, 440, 531, 18))
        self.status.setObjectName("status")
        self.solution_type = QtWidgets.QLabel(self.centralwidget)
        self.solution_type.setGeometry(QtCore.QRect(260, 460, 531, 18))
        self.solution_type.setObjectName("solution_type")
        self.solution_value = QtWidgets.QLabel(self.centralwidget)
        self.solution_value.setGeometry(QtCore.QRect(260, 480, 201, 18))
        self.solution_value.setObjectName("solution_value")
        self.ub_value = QtWidgets.QLabel(self.centralwidget)
        self.ub_value.setGeometry(QtCore.QRect(260, 500, 231, 18))
        self.ub_value.setObjectName("ub_value")
        self.loss_progress = QtWidgets.QProgressBar(self.centralwidget)
        self.loss_progress.setGeometry(QtCore.QRect(190, 520, 291, 23))
        self.loss_progress.setProperty("value", 0)
        self.loss_progress.setObjectName("loss_progress")
        self.pushButton = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton.setGeometry(QtCore.QRect(140, 310, 121, 34))
        self.pushButton.setObjectName("pushButton")
        self.label_7 = QtWidgets.QLabel(self.centralwidget)
        self.label_7.setGeometry(QtCore.QRect(140, 90, 58, 18))
        self.label_7.setObjectName("label_7")
        self.label_8 = QtWidgets.QLabel(self.centralwidget)
        self.label_8.setGeometry(QtCore.QRect(270, 90, 58, 18))
        self.label_8.setObjectName("label_8")
        self.label_9 = QtWidgets.QLabel(self.centralwidget)
        self.label_9.setGeometry(QtCore.QRect(400, 90, 58, 18))
        self.label_9.setObjectName("label_9")
        self.solver_edit_button = QtWidgets.QPushButton(self.centralwidget)
        self.solver_edit_button.setGeometry(QtCore.QRect(10, 310, 121, 34))
        self.solver_edit_button.setObjectName("solver_edit_button")
        self.teacher_list = QtWidgets.QListWidget(self.centralwidget)
        self.teacher_list.setGeometry(QtCore.QRect(140, 110, 121, 192))
        self.teacher_list.setObjectName("teacher_list")
        self.subject_list = QtWidgets.QListWidget(self.centralwidget)
        self.subject_list.setGeometry(QtCore.QRect(270, 110, 121, 192))
        self.subject_list.setObjectName("subject_list")
        self.groups_list = QtWidgets.QListWidget(self.centralwidget)
        self.groups_list.setGeometry(QtCore.QRect(400, 110, 121, 192))
        self.groups_list.setObjectName("groups_list")
        self.save_problem_button = QtWidgets.QPushButton(self.centralwidget)
        self.save_problem_button.setGeometry(QtCore.QRect(10, 400, 101, 34))
        self.save_problem_button.setObjectName("save_problem_button")
        self.export_solution_button = QtWidgets.QPushButton(self.centralwidget)
        self.export_solution_button.setGeometry(QtCore.QRect(120, 400, 111, 34))
        self.export_solution_button.setObjectName("export_solution_button")
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 802, 30))
        self.menubar.setObjectName("menubar")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "pySprida"))
        self.label.setText(_translate("MainWindow", "Config File"))
        self.config_path_select_button.setText(_translate("MainWindow", "Browse"))
        self.load_config_button.setText(_translate("MainWindow", "Load"))
        self.generate_button.setText(_translate("MainWindow", "Generate"))
        self.solver_selector.setItemText(0, _translate("MainWindow", "LP"))
        self.label_2.setText(_translate("MainWindow", "Solver"))
        self.label_3.setText(_translate("MainWindow", "Status:"))
        self.label_4.setText(_translate("MainWindow", "Type:"))
        self.label_5.setText(_translate("MainWindow", "Solution:"))
        self.label_6.setText(_translate("MainWindow", "UB:"))
        self.status.setText(_translate("MainWindow", "-"))
        self.solution_type.setText(_translate("MainWindow", "-"))
        self.solution_value.setText(_translate("MainWindow", "-"))
        self.ub_value.setText(_translate("MainWindow", "-"))
        self.pushButton.setText(_translate("MainWindow", "Edit Teachers"))
        self.label_7.setText(_translate("MainWindow", "Teacher"))
        self.label_8.setText(_translate("MainWindow", "Subjects"))
        self.label_9.setText(_translate("MainWindow", "Groups"))
        self.solver_edit_button.setText(_translate("MainWindow", "Edit Solver"))
        self.save_problem_button.setText(_translate("MainWindow", "Save problem"))
        self.export_solution_button.setText(_translate("MainWindow", "Export solution "))
