# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'lpsolveredit.ui'
#
# Created by: PyQt5 UI code generator 5.15.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_LPSolverEdit(object):
    def setupUi(self, LPSolverEdit):
        LPSolverEdit.setObjectName("LPSolverEdit")
        LPSolverEdit.resize(328, 182)
        self.centralwidget = QtWidgets.QWidget(LPSolverEdit)
        self.centralwidget.setObjectName("centralwidget")
        self.label = QtWidgets.QLabel(self.centralwidget)
        self.label.setGeometry(QtCore.QRect(30, 10, 91, 18))
        self.label.setObjectName("label")
        self.label_2 = QtWidgets.QLabel(self.centralwidget)
        self.label_2.setGeometry(QtCore.QRect(30, 50, 131, 18))
        self.label_2.setObjectName("label_2")
        self.label_3 = QtWidgets.QLabel(self.centralwidget)
        self.label_3.setGeometry(QtCore.QRect(30, 90, 141, 18))
        self.label_3.setObjectName("label_3")
        self.max_time = QtWidgets.QLineEdit(self.centralwidget)
        self.max_time.setGeometry(QtCore.QRect(190, 10, 113, 32))
        self.max_time.setObjectName("max_time")
        self.equal_lesson_weight = QtWidgets.QLineEdit(self.centralwidget)
        self.equal_lesson_weight.setGeometry(QtCore.QRect(190, 50, 113, 32))
        self.equal_lesson_weight.setObjectName("equal_lesson_weight")
        self.equal_subject_weight = QtWidgets.QLineEdit(self.centralwidget)
        self.equal_subject_weight.setGeometry(QtCore.QRect(190, 90, 113, 32))
        self.equal_subject_weight.setObjectName("equal_subject_weight")
        LPSolverEdit.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(LPSolverEdit)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 328, 30))
        self.menubar.setObjectName("menubar")
        LPSolverEdit.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(LPSolverEdit)
        self.statusbar.setObjectName("statusbar")
        LPSolverEdit.setStatusBar(self.statusbar)

        self.retranslateUi(LPSolverEdit)
        QtCore.QMetaObject.connectSlotsByName(LPSolverEdit)

    def retranslateUi(self, LPSolverEdit):
        _translate = QtCore.QCoreApplication.translate
        LPSolverEdit.setWindowTitle(_translate("LPSolverEdit", "LP Solver Edit"))
        self.label.setText(_translate("LPSolverEdit", "Max time (sec)"))
        self.label_2.setText(_translate("LPSolverEdit", "Equal lessons weight"))
        self.label_3.setText(_translate("LPSolverEdit", "Equal subjects weight"))
